@@ -1,5 +1,5 @@
 /* EasyTAG - Tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  * Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 #include "browser.h"
 #include "file_description.h"
 #include "file_list.h"
+#include "id3_tag.h"
 #include "log.h"
 #include "misc.h"
 #include "cddb_dialog.h"
@@ -148,6 +149,7 @@ Save_List_Of_Files (GList *etfilelist, gboolean force_saving_files)
     File_Name *FileNameNew;
     double     fraction;
     GAction *action;
+    GVariant *variant;
     GtkWidget *widget_focused;
     GtkTreePath *currentPath = NULL;
 
@@ -345,7 +347,17 @@ Save_List_Of_Files (GList *etfilelist, gboolean force_saving_files)
                                                           etfile_save_position,
                                                           TRUE);
 
-    et_application_window_browser_toggle_display_mode (window);
+    /* FIXME: Find out why this is a special case for the artist/album mode. */
+    action = g_action_map_lookup_action (G_ACTION_MAP (MainWindow),
+                                         "file-artist-view");
+    variant = g_action_get_state (action);
+
+    if (strcmp (g_variant_get_string (variant, NULL), "artist") == 0)
+    {
+        et_application_window_browser_toggle_display_mode (window);
+    }
+
+    g_variant_unref (variant);
 
     /* To update state of command buttons */
     et_application_window_update_actions (ET_APPLICATION_WINDOW (MainWindow));
@@ -744,15 +756,47 @@ Write_File_Tag (ET_File *ETFile, gboolean hide_msgbox)
 
     if (!hide_msgbox)
     {
-        msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
-                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                             GTK_MESSAGE_ERROR,
-                             GTK_BUTTONS_CLOSE,
-                             _("Cannot write tag in file ‘%s’"),
-                             basename_utf8);
-        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
-                                                  "%s", error->message);
-        gtk_window_set_title(GTK_WINDOW(msgdialog),_("Tag Write Error"));
+        if (g_error_matches (error, ET_ID3_ERROR, ET_ID3_ERROR_BUGGY_ID3LIB))
+        {
+            msgdialog = gtk_message_dialog_new (GTK_WINDOW (MainWindow),
+                                                GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                GTK_MESSAGE_ERROR,
+                                                GTK_BUTTONS_CLOSE,
+                                                "%s",
+                                                _("You have tried to save "
+                                                "this tag to Unicode but it "
+                                                "was detected that your "
+                                                "version of id3lib is buggy"));
+            gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
+                                                      _("If you reload this "
+                                                      "file, some characters "
+                                                      "in the tag may not be "
+                                                      "displayed correctly. "
+                                                      "Please, apply the "
+                                                      "patch "
+                                                      "src/id3lib/patch_id3lib_3.8.3_UTF16_writing_bug.diff "
+                                                      "to id3lib, which is "
+                                                      "available in the "
+                                                      "EasyTAG package "
+                                                      "sources.\nNote that "
+                                                      "this message will "
+                                                      "appear only "
+                                                      "once.\n\nFile: %s"),
+                                                      basename_utf8);
+        }
+        else
+        {
+            msgdialog = gtk_message_dialog_new (GTK_WINDOW (MainWindow),
+                                                GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                GTK_MESSAGE_ERROR,
+                                                GTK_BUTTONS_CLOSE,
+                                                _("Cannot write tag in file ‘%s’"),
+                                                basename_utf8);
+            gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
+                                                      "%s", error->message);
+            gtk_window_set_title (GTK_WINDOW (msgdialog),
+                                  _("Tag Write Error"));
+        }
 
         gtk_dialog_run(GTK_DIALOG(msgdialog));
         gtk_widget_destroy(msgdialog);
@@ -821,21 +865,21 @@ Read_Directory (const gchar *path_real)
     {
         // Message if the directory doesn't exist...
         GtkWidget *msgdialog;
-        gchar *path_utf8 = filename_to_display(path_real);
+        gchar *display_path = g_filename_display_name (path_real);
 
         msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
                                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                            GTK_MESSAGE_ERROR,
                                            GTK_BUTTONS_CLOSE,
                                            _("Cannot read directory ‘%s’"),
-                                           path_utf8);
+                                           display_path);
         gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
                                                   "%s", error->message);
         gtk_window_set_title(GTK_WINDOW(msgdialog),_("Directory Read Error"));
 
         gtk_dialog_run(GTK_DIALOG(msgdialog));
         gtk_widget_destroy(msgdialog);
-        g_free(path_utf8);
+        g_free (display_path);
 
         ReadingDirectory = FALSE; //Allow a new reading
         et_application_window_browser_set_sensitive (window, TRUE);
@@ -875,13 +919,13 @@ Read_Directory (const gchar *path_real)
     {
         GFile *file = l->data;
         gchar *filename_real = g_file_get_path (file);
-        gchar *filename_utf8 = filename_to_display(filename_real);
+        gchar *display_path = g_filename_display_name (filename_real);
 
-        msg = g_strdup_printf (_("File: ‘%s’"), filename_utf8);
+        msg = g_strdup_printf (_("File: ‘%s’"), display_path);
         et_application_window_status_bar_message (window, msg, FALSE);
         g_free(msg);
-        g_free(filename_utf8);
         g_free (filename_real);
+        g_free (display_path);
 
         ETCore->ETFileList = et_file_list_add (ETCore->ETFileList, file);
 
@@ -1007,8 +1051,8 @@ read_directory_recursively (GList *file_list, GFileEnumerator *dir_enumerator,
                 if (recurse)
                 {
                     /* Searching for files recursively. */
-                    GFile *child_dir = g_file_get_child (g_file_enumerator_get_container (dir_enumerator),
-                                                         file_name);
+                    GFile *child_dir = g_file_enumerator_get_child (dir_enumerator,
+                                                                    info);
                     GFileEnumerator *childdir_enumerator;
                     GError *child_error = NULL;
                     childdir_enumerator = g_file_enumerate_children (child_dir,
@@ -1019,9 +1063,18 @@ read_directory_recursively (GList *file_list, GFileEnumerator *dir_enumerator,
                                                                      NULL, &child_error);
                     if (!childdir_enumerator)
                     {
+                        gchar *child_path;
+                        gchar *display_path;
+
+                        child_path = g_file_get_path (child_dir);
+                        display_path = g_filename_display_name (child_path);
+
                         Log_Print (LOG_ERROR,
                                    _("Error opening directory ‘%s’: %s"),
-                                   file_name, child_error->message);
+                                   display_path, child_error->message);
+
+                        g_free (display_path);
+                        g_free (child_path);
                         g_error_free (child_error);
                         g_object_unref (child_dir);
                         g_object_unref (info);
@@ -1039,9 +1092,7 @@ read_directory_recursively (GList *file_list, GFileEnumerator *dir_enumerator,
             else if (type == G_FILE_TYPE_REGULAR &&
                      et_file_is_supported (file_name))
             {
-                /* TODO: Use g_file_enumerator_get_child(). */
-                GFile *file = g_file_get_child (g_file_enumerator_get_container (dir_enumerator),
-                                                file_name);
+                GFile *file = g_file_enumerator_get_child (dir_enumerator, info);
                 file_list = g_list_append (file_list, file);
             }
 
