@@ -25,20 +25,10 @@ G_BEGIN_DECLS
 
 #include "core_types.h"
 #include "file_description.h"
+#include "file_info.h"
+#include "file_name.h"
 #include "file_tag.h"
 
-/*
- * Description of each item of the FileNameList list
- */
-typedef struct
-{
-    guint key;
-    gboolean saved;        /* Set to TRUE if this filename had been saved */
-    gchar *value;          /* The filename containing the full path and the extension of the file */
-    gchar *value_utf8;     /* Same than "value", but converted to UTF-8 to avoid multiple call to the convertion function */
-    gchar *value_ck;       /* Collate key of "value_utf8" to speed up comparaison */
-} File_Name;
-
 /*
  * Description of each item of the ETFileList list
  */
@@ -75,20 +65,13 @@ typedef struct
 gboolean ET_Check_If_File_Is_Saved (const ET_File *ETFile);
 
 ET_File * ET_File_Item_New (void);
-ET_File_Info * ET_File_Info_Item_New (void);
-File_Name * ET_File_Name_Item_New (void);
 void ET_Free_File_List_Item (ET_File *ETFile);
 
-gboolean ET_Set_Filename_File_Name_Item (File_Name *FileName, const gchar *filename_utf8, const gchar *filename);
-
-void ET_Display_File_Data_To_UI (ET_File *ETFile);
 void ET_Save_File_Data_From_UI (ET_File *ETFile);
 gboolean ET_Save_File_Name_Internal (const ET_File *ETFile, File_Name *FileName);
 gboolean ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error);
 gboolean ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag);
 
-guint ET_Undo_Key_New (void);
-
 gboolean ET_Undo_File_Data (ET_File *ETFile);
 gboolean ET_Redo_File_Data (ET_File *ETFile);
 gboolean ET_File_Data_Has_Undo_Data (const ET_File *ETFile);
@@ -96,8 +79,8 @@ gboolean ET_File_Data_Has_Redo_Data (const ET_File *ETFile);
 
 gboolean ET_Manage_Changes_Of_File_Data (ET_File *ETFile, File_Name *FileName, File_Tag *FileTag);
 void ET_Mark_File_Name_As_Saved (ET_File *ETFile);
-gboolean ET_File_Name_Convert_Character (gchar *filename_utf8);
 gchar *ET_File_Name_Generate (const ET_File *ETFile, const gchar *new_file_name);
+gchar * ET_File_Format_File_Extension (const ET_File *ETFile);
 
 gint ET_Comp_Func_Sort_File_By_Ascending_Filename (const ET_File *ETFile1, const ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Descending_Filename (const ET_File *ETFile1, const ET_File *ETFile2);
