@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2016  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -210,7 +210,6 @@ et_file_list_add (GList *file_list,
     GFileInfo *fileinfo;
     gchar *filename;
     gchar *display_path;
-    const gchar  *locale_lc_ctype = getenv("LC_CTYPE");
     GError *error = NULL;
     gboolean success;
 
@@ -236,12 +235,6 @@ et_file_list_add (GList *file_list,
     FileTag = et_file_tag_new ();
     FileTag->saved = TRUE;    /* The file hasn't been changed, so it's saved */
 
-    /* Patch from Doruk Fisek and Onur Kucuk: avoid upper/lower conversion bugs
-     * (like I->i conversion in some locales) in tag parsing. The problem occurs
-     * for example with Turkish language where it can't read 'TITLE=' field if
-     * it is written as 'Title=' in the file */
-    setlocale(LC_CTYPE, "C");
-
     switch (description->TagType)
     {
 #ifdef ENABLE_MP3
@@ -444,9 +437,6 @@ et_file_list_add (GList *file_list,
         g_error_free (error);
     }
 
-    /* Restore previous value */
-    setlocale(LC_CTYPE, locale_lc_ctype ? locale_lc_ctype : "");
-
     /* Store the modification time of the file to check if the file was changed
      * before saving */
     fileinfo = g_file_query_info (file, G_FILE_ATTRIBUTE_TIME_MODIFIED,
@@ -537,22 +527,29 @@ ET_Comp_Func_Sort_Artist_Item_By_Ascending_Artist (const GList *AlbumList1,
     const gchar *etfile1_artist;
     const gchar *etfile2_artist;
 
-    if (!AlbumList1
-    || !(etfilelist1    = (GList *)AlbumList1->data)
-    || !(etfile1        = (ET_File *)etfilelist1->data)
-    || !(etfile1_artist = ((File_Tag *)etfile1->FileTag->data)->artist) )
+    if (!AlbumList1 || !(etfilelist1 = (GList *)AlbumList1->data)
+        || !(etfile1 = (ET_File *)etfilelist1->data))
+    {
         return -1;
+    }
 
-    if (!AlbumList2
-    || !(etfilelist2    = (GList *)AlbumList2->data)
-    || !(etfile2        = (ET_File *)etfilelist2->data)
-    || !(etfile2_artist = ((File_Tag *)etfile2->FileTag->data)->artist) )
+    if (!AlbumList2 || !(etfilelist2 = (GList *)AlbumList2->data)
+        || !(etfile2 = (ET_File *)etfilelist2->data))
+    {
         return 1;
+    }
 
-    /*if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-     *    return strcmp(etfile1_artist,etfile2_artist); */
-    //else
-        return strcasecmp(etfile1_artist,etfile2_artist);
+    etfile1_artist = ((File_Tag *)etfile1->FileTag->data)->artist;
+    etfile2_artist = ((File_Tag *)etfile2->FileTag->data)->artist;
+
+    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
+    {
+        return et_normalized_strcmp0 (etfile1_artist, etfile2_artist);
+    }
+    else
+    {
+        return et_normalized_strcasecmp0 (etfile1_artist, etfile2_artist);
+    }
 }
 
 /*
@@ -567,20 +564,27 @@ ET_Comp_Func_Sort_Album_Item_By_Ascending_Album (const GList *etfilelist1,
     const gchar *etfile1_album;
     const gchar *etfile2_album;
 
-    if (!etfilelist1
-    || !(etfile1        = (ET_File *)etfilelist1->data)
-    || !(etfile1_album  = ((File_Tag *)etfile1->FileTag->data)->album) )
+    if (!etfilelist1 || !(etfile1 = (ET_File *)etfilelist1->data))
+    {
         return -1;
+    }
 
-    if (!etfilelist2
-    || !(etfile2        = (ET_File *)etfilelist2->data)
-    || !(etfile2_album  = ((File_Tag *)etfile2->FileTag->data)->album) )
+    if (!etfilelist2 || !(etfile2 = (ET_File *)etfilelist2->data))
+    {
         return 1;
+    }
 
-    /*if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-     *    return strcmp(etfile1_album,etfile2_album); */
-    //else
-        return strcasecmp(etfile1_album,etfile2_album);
+    etfile1_album  = ((File_Tag *)etfile1->FileTag->data)->album;
+    etfile2_album  = ((File_Tag *)etfile2->FileTag->data)->album;
+
+    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
+    {
+        return et_normalized_strcmp0 (etfile1_album, etfile2_album);
+    }
+    else
+    {
+        return et_normalized_strcasecmp0 (etfile1_album, etfile2_album);
+    }
 }
 
 /*
