@@ -275,6 +275,9 @@ create_preferences_dialog (EtPreferencesDialog *self)
 
     priv = et_preferences_dialog_get_instance_private (self);
 
+    /* The window */
+    gtk_dialog_add_buttons (GTK_DIALOG (self), _("_Close"), GTK_RESPONSE_CLOSE,
+                            NULL);
     gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_CLOSE);
 
     /* Browser. */
