@@ -27,6 +27,24 @@ G_BEGIN_DECLS
 
 #define ID3_INVALID_GENRE 255
 
+/*
+ * Error domain and codes for errors while reading/writing ID3 tags.
+ */
+GQuark et_id3_error_quark (void);
+
+#define ET_ID3_ERROR et_id3_error_quark ()
+
+/*
+ * EtID3Error:
+ * @ET_ID3_ERROR_BUGGY_ID3LIB: Buggy id3lib implementation found
+ *
+ * Errors that can occur when dealing with ID3 tags.
+ */
+typedef enum
+{
+    ET_ID3_ERROR_BUGGY_ID3LIB
+} EtID3Error;
+
 gboolean id3tag_read_file_tag (GFile *file, File_Tag *FileTag, GError **error);
 gboolean id3tag_write_file_v24tag (const ET_File *ETFile, GError **error);
 gboolean id3tag_write_file_tag (const ET_File *ETFile, GError **error);
@@ -35,6 +53,7 @@ const gchar * Id3tag_Genre_To_String (unsigned char genre_code);
 guchar Id3tag_String_To_Genre (const gchar *genre);
 
 gchar *et_id3tag_get_tpos_from_file_tag (const File_Tag *file_tag);
+gboolean et_id3tag_check_if_file_is_valid (GFile *file, GError **error);
 
 G_END_DECLS
 
