@@ -443,7 +443,9 @@ id3tag_read_file_tag (GFile *gfile,
         tmpupdate = libid3tag_Get_Frame_Str(frame, ~0, &string1);
         if (string1)
         {
-            if (strncasecmp(string1, EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR, strlen(EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR)) == 0)
+            if (strncmp (string1,
+                         EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR,
+                         strlen (EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR)) == 0)
             {
                 FileTag->encoded_by = g_strdup(&string1[sizeof(EASYTAG_STRING_ENCODEDBY) + sizeof(MULTIFIELD_SEPARATOR) - 2]);
                 g_free(string1);
@@ -1264,7 +1266,7 @@ Id3tag_delete_txxframes(struct id3_tag *tag, const gchar *param1, int start)
         {
             str = NULL;
             if ((str = (gchar *)id3_ucs4_latin1duplicate(ucs4string))
-            && (strncasecmp(str, param1, strlen(param1)) == 0) )
+            && (g_ascii_strncasecmp (str, param1, strlen (param1)) == 0))
             {
                 g_free(str);
                 id3_tag_detachframe(tag, frame);
