@@ -526,6 +526,12 @@ vcedit_open (EtOggState *state,
             headerpackets = 2;
 #endif
             break;
+#ifndef ENABLE_SPEEX
+        case ET_OGG_KIND_SPEEX:
+#endif
+#ifndef ENABLE_OPUS
+        case ET_OGG_KIND_OPUS:
+#endif
         case ET_OGG_KIND_UNKNOWN:
         default:
             g_assert_not_reached ();
@@ -604,6 +610,9 @@ vcedit_open (EtOggState *state,
                                                      header->packet,
                                                      header->bytes))
                             {
+                                case 0:
+                                    break;
+
                                 case OP_ENOTFORMAT:
                                     g_set_error (error, ET_OGG_ERROR,
                                                  ET_OGG_ERROR_HEADER,
@@ -629,6 +638,9 @@ vcedit_open (EtOggState *state,
                                     break;
                             }
                             break;
+#endif
+#ifndef ENABLE_OPUS
+                        case ET_OGG_KIND_OPUS:
 #endif
                         case ET_OGG_KIND_UNKNOWN:
                         default:
